#ifndef CF_DATACUBE_H
#define CF_DATACUBE_H

#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct CfDataCube {
  double* data;
  size_t length;
  size_t rows;
  size_t cols;
} CfDataCube;

#ifdef __cplusplus
}
#endif

#endif
